@@ -59,17 +59,19 @@ K_PLUGIN_FACTORY_WITH_JSON(
 namespace Breeze
 {
 
+    using KDecoration2::ColorRole;
+    using KDecoration2::ColorGroup;
 
     //________________________________________________________________
     static int g_sDecoCount = 0;
     static int g_shadowSize = 0;
     static int g_shadowStrength = 0;
+    static QColor g_shadowColor = Qt::black;
     static QSharedPointer<KDecoration2::DecorationShadow> g_sShadow;
 
     //________________________________________________________________
     Decoration::Decoration(QObject *parent, const QVariantList &args)
         : KDecoration2::Decoration(parent, args)
-        , m_colorSettings()
         , m_animation( new QPropertyAnimation( this ) )
     {
         g_sDecoCount++;
@@ -102,24 +104,30 @@ namespace Breeze
     QColor Decoration::titleBarColor() const
     {
 
-        if( hideTitleBar() ) return m_colorSettings.titleBar( false );
+        auto c = client().data();
+        if( hideTitleBar() ) return c->color( ColorGroup::Inactive, ColorRole::TitleBar );
         else if( m_animation->state() == QPropertyAnimation::Running )
         {
-            return KColorUtils::mix( m_colorSettings.inactiveTitleBar(), m_colorSettings.activeTitleBar(), m_opacity );
-        } else return m_colorSettings.titleBar( client().data()->isActive() );
+            return KColorUtils::mix(
+                c->color( ColorGroup::Inactive, ColorRole::TitleBar ),
+                c->color( ColorGroup::Active, ColorRole::TitleBar ),
+                m_opacity );
+        } else return c->color( c->isActive() ? ColorGroup::Active : ColorGroup::Inactive, ColorRole::TitleBar );
 
     }
 
     //________________________________________________________________
     QColor Decoration::outlineColor() const
     {
+
+        auto c( client().data() );
         if( !m_useSeparator ) return QColor();
         if( m_animation->state() == QPropertyAnimation::Running )
         {
-            QColor color( m_colorSettings.palette().color( QPalette::Highlight ) );
+            QColor color( c->palette().color( QPalette::Highlight ) );
             color.setAlpha( color.alpha()*m_opacity );
             return color;
-        } else if( client().data()->isActive() ) return m_colorSettings.palette().color( QPalette::Highlight );
+        } else if( c->isActive() ) return c->palette().color( QPalette::Highlight );
         else return QColor();
     }
 
@@ -127,19 +135,22 @@ namespace Breeze
     QColor Decoration::fontColor() const
     {
 
+        auto c = client().data();
         if( m_animation->state() == QPropertyAnimation::Running )
         {
-            return KColorUtils::mix( m_colorSettings.inactiveFont(), m_colorSettings.activeFont(), m_opacity );
-        } else return m_colorSettings.font( client().data()->isActive() );
+            return KColorUtils::mix(
+                c->color( ColorGroup::Inactive, ColorRole::Foreground ),
+                c->color( ColorGroup::Active, ColorRole::Foreground ),
+                m_opacity );
+        } else return  c->color( c->isActive() ? ColorGroup::Active : ColorGroup::Inactive, ColorRole::Foreground );
 
     }
 
     //________________________________________________________________
     void Decoration::init()
     {
-        m_colorSettings.update(client().data()->palette(), *client().data());
-        m_useSeparator = (m_colorSettings.palette().color( QPalette::Window ) != m_colorSettings.activeTitleBar() );
-
+        auto c = client().data();
+        m_useSeparator = (c->palette().color( QPalette::Window ) != c->color( ColorGroup::Active, ColorRole::TitleBar ) );
 
         // active state change animation
         m_animation->setStartValue( 0 );
@@ -161,10 +172,10 @@ namespace Breeze
         connect(s.data(), &KDecoration2::DecorationSettings::reconfigured, this, &Decoration::reconfigure);
         connect(s.data(), &KDecoration2::DecorationSettings::reconfigured, SettingsProvider::self(), &SettingsProvider::reconfigure, Qt::UniqueConnection );
 
-        connect(client().data(), &KDecoration2::DecoratedClient::adjacentScreenEdgesChanged, this, &Decoration::recalculateBorders);
-        connect(client().data(), &KDecoration2::DecoratedClient::maximizedHorizontallyChanged, this, &Decoration::recalculateBorders);
-        connect(client().data(), &KDecoration2::DecoratedClient::maximizedVerticallyChanged, this, &Decoration::recalculateBorders);
-        connect(client().data(), &KDecoration2::DecoratedClient::captionChanged, this,
+        connect(c, &KDecoration2::DecoratedClient::adjacentScreenEdgesChanged, this, &Decoration::recalculateBorders);
+        connect(c, &KDecoration2::DecoratedClient::maximizedHorizontallyChanged, this, &Decoration::recalculateBorders);
+        connect(c, &KDecoration2::DecoratedClient::maximizedVerticallyChanged, this, &Decoration::recalculateBorders);
+        connect(c, &KDecoration2::DecoratedClient::captionChanged, this,
             [this]()
             {
                 // update the caption area
@@ -172,22 +183,22 @@ namespace Breeze
             }
         );
 
-        connect(client().data(), &KDecoration2::DecoratedClient::activeChanged, this, &Decoration::updateAnimationState);
-        connect(client().data(), &KDecoration2::DecoratedClient::paletteChanged, this,
+        connect(c, &KDecoration2::DecoratedClient::activeChanged, this, &Decoration::updateAnimationState);
+        connect(c, &KDecoration2::DecoratedClient::paletteChanged, this,
             [this]() {
-                m_colorSettings.update(client().data()->palette(), *client().data());
-                m_useSeparator = (m_colorSettings.palette().color( QPalette::Window ) != m_colorSettings.activeTitleBar() );
+                auto c = client().data();
+                m_useSeparator = (c->palette().color( QPalette::Window ) != c->color( ColorGroup::Active, ColorRole::TitleBar ) );
                 update();
             }
         );
-        connect(client().data(), &KDecoration2::DecoratedClient::widthChanged, this, &Decoration::updateTitleBar);
-        connect(client().data(), &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateTitleBar);
-        connect(client().data(), &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::setOpaque);
+        connect(c, &KDecoration2::DecoratedClient::widthChanged, this, &Decoration::updateTitleBar);
+        connect(c, &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateTitleBar);
+        connect(c, &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::setOpaque);
 
-        connect(client().data(), &KDecoration2::DecoratedClient::widthChanged, this, &Decoration::updateButtonsGeometry);
-        connect(client().data(), &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateButtonsGeometry);
-        connect(client().data(), &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::recalculateBorders);
-        connect(client().data(), &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::updateButtonsGeometry);
+        connect(c, &KDecoration2::DecoratedClient::widthChanged, this, &Decoration::updateButtonsGeometry);
+        connect(c, &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateButtonsGeometry);
+        connect(c, &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::recalculateBorders);
+        connect(c, &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::updateButtonsGeometry);
 
         createButtons();
         createShadow();
@@ -197,8 +208,9 @@ namespace Breeze
     void Decoration::updateTitleBar()
     {
         auto s = settings();
+        auto c = client().data();
         const bool maximized = isMaximized();
-        const int width =  maximized ? client().data()->width() : client().data()->width() - 2*s->largeSpacing()*Metrics::TitleBar_SideMargin;
+        const int width =  maximized ? c->width() : c->width() - 2*s->largeSpacing()*Metrics::TitleBar_SideMargin;
         const int height = maximized ? borderTop() : borderTop() - s->smallSpacing()*Metrics::TitleBar_TopMargin;
         const int x = maximized ? 0 : s->largeSpacing()*Metrics::TitleBar_SideMargin;
         const int y = maximized ? 0 : s->smallSpacing()*Metrics::TitleBar_TopMargin;
@@ -211,7 +223,8 @@ namespace Breeze
         if( m_internalSettings->animationsEnabled() )
         {
 
-            m_animation->setDirection( client().data()->isActive() ? QPropertyAnimation::Forward : QPropertyAnimation::Backward );
+            auto c = client().data();
+            m_animation->setDirection( c->isActive() ? QPropertyAnimation::Forward : QPropertyAnimation::Backward );
             if( m_animation->state() != QPropertyAnimation::Running ) m_animation->start();
 
         } else {
@@ -416,15 +429,16 @@ namespace Breeze
     void Decoration::paint(QPainter *painter, const QRect &repaintRegion)
     {
         // TODO: optimize based on repaintRegion
+        auto c = client().data();
 
         // paint background
-        if( !client().data()->isShaded() )
+        if( !c->isShaded() )
         {
             painter->fillRect(rect(), Qt::transparent);
             painter->save();
             painter->setRenderHint(QPainter::Antialiasing);
             painter->setPen(Qt::NoPen);
-            painter->setBrush(m_colorSettings.frame(client().data()->isActive()));
+            painter->setBrush( c->color( c->isActive() ? ColorGroup::Active : ColorGroup::Inactive, ColorRole::Frame ) );
 
             // clip away the top part
             if( !hideTitleBar() ) painter->setClipRect(0, borderTop(), size().width(), size().height() - borderTop(), Qt::IntersectClip);
@@ -485,7 +499,7 @@ namespace Breeze
 
         // draw caption
         painter->setFont(s->font());
-        painter->setPen(m_colorSettings.font(c->isActive()));
+        painter->setPen( fontColor() );
         const auto cR = captionRect();
         const QString caption = painter->fontMetrics().elidedText(c->caption(), Qt::ElideMiddle, cR.first.width());
         painter->drawText(cR.first, cR.second | Qt::TextSingleLine, caption);
@@ -501,11 +515,12 @@ namespace Breeze
         const int baseSize = settings()->gridUnit();
         switch( m_internalSettings->buttonSize() )
         {
-            case Breeze::InternalSettings::ButtonSmall: return baseSize*1.5;
+            case InternalSettings::ButtonTiny: return baseSize;
+            case InternalSettings::ButtonSmall: return baseSize*1.5;
             default:
-            case Breeze::InternalSettings::ButtonDefault: return baseSize*2;
-            case Breeze::InternalSettings::ButtonLarge: return baseSize*2.5;
-            case Breeze::InternalSettings::ButtonVeryLarge: return baseSize*3.5;
+            case InternalSettings::ButtonDefault: return baseSize*2;
+            case InternalSettings::ButtonLarge: return baseSize*2.5;
+            case InternalSettings::ButtonVeryLarge: return baseSize*3.5;
         }
 
     }
@@ -520,6 +535,7 @@ namespace Breeze
         if( hideTitleBar() ) return qMakePair( QRect(), Qt::AlignCenter );
         else {
 
+            auto c = client().data();
             const int leftOffset = m_leftButtons->buttons().isEmpty() ?
                 Metrics::TitleBar_SideMargin*settings()->smallSpacing():
                 m_leftButtons->geometry().x() + m_leftButtons->geometry().width() + Metrics::TitleBar_SideMargin*settings()->smallSpacing();
@@ -533,22 +549,22 @@ namespace Breeze
 
             switch( m_internalSettings->titleAlignment() )
             {
-                case Breeze::InternalSettings::AlignLeft:
+                case InternalSettings::AlignLeft:
                 return qMakePair( maxRect, Qt::AlignVCenter|Qt::AlignLeft );
 
-                case Breeze::InternalSettings::AlignRight:
+                case InternalSettings::AlignRight:
                 return qMakePair( maxRect, Qt::AlignVCenter|Qt::AlignRight );
 
-                case Breeze::InternalSettings::AlignCenter:
+                case InternalSettings::AlignCenter:
                 return qMakePair( maxRect, Qt::AlignCenter );
 
                 default:
-                case Breeze::InternalSettings::AlignCenterFullWidth:
+                case InternalSettings::AlignCenterFullWidth:
                 {
 
                     // full caption rect
                     const QRect fullRect = QRect( 0, yOffset, size().width(), captionHeight() );
-                    QRect boundingRect( settings()->fontMetrics().boundingRect( client().data()->caption()).toRect() );
+                    QRect boundingRect( settings()->fontMetrics().boundingRect( c->caption()).toRect() );
 
                     // text bounding rect
                     boundingRect.setTop( yOffset );
@@ -572,74 +588,77 @@ namespace Breeze
     {
 
         // assign global shadow if exists and parameters match
-        if( g_sShadow && g_shadowSize == m_internalSettings->shadowSize() && g_shadowStrength == m_internalSettings->shadowStrength() )
+        if(
+            !g_sShadow  ||
+            g_shadowSize != m_internalSettings->shadowSize() ||
+            g_shadowStrength != m_internalSettings->shadowStrength() ||
+            g_shadowColor != m_internalSettings->shadowColor()
+            )
         {
-            setShadow(g_sShadow);
-            return;
+            // assign parameters
+            g_shadowSize = m_internalSettings->shadowSize();
+            g_shadowStrength = m_internalSettings->shadowStrength();
+            g_shadowColor = m_internalSettings->shadowColor();
+            const int shadowOffset = qMax( 6*g_shadowSize/16, Metrics::Shadow_Overlap*2 );
+
+            // create image
+            QImage image(2*g_shadowSize, 2*g_shadowSize, QImage::Format_ARGB32_Premultiplied);
+            image.fill(Qt::transparent);
+
+            // create gradient
+            // gaussian delta function
+            auto alpha = [](qreal x) { return std::exp( -x*x/0.15 ); };
+
+            // color calculation delta function
+            auto gradientStopColor = [](QColor color, int alpha)
+            {
+                color.setAlpha(alpha);
+                return color;
+            };
+
+            QRadialGradient radialGradient( g_shadowSize, g_shadowSize, g_shadowSize );
+            for( int i = 0; i < 10; ++i )
+            {
+                const qreal x( qreal( i )/9 );
+                radialGradient.setColorAt(x,  gradientStopColor( g_shadowColor, alpha(x)*g_shadowStrength ) );
+            }
+
+            radialGradient.setColorAt(1, gradientStopColor( g_shadowColor, 0 ) );
+
+            // fill
+            QPainter painter(&image);
+            painter.setCompositionMode(QPainter::CompositionMode_Source);
+            painter.fillRect( image.rect(), radialGradient);
+
+            // contrast pixel
+            painter.setBrush( Qt::NoBrush );
+            painter.setPen( gradientStopColor( g_shadowColor, g_shadowStrength ) );
+            painter.setRenderHints(QPainter::Antialiasing );
+            painter.drawRoundedRect( QRect( g_shadowSize-shadowOffset, g_shadowSize-shadowOffset, shadowOffset, shadowOffset ), 3, 3 );
+            painter.end();
+
+
+            g_sShadow = QSharedPointer<KDecoration2::DecorationShadow>::create();
+            g_sShadow->setPadding( QMargins(
+                g_shadowSize-shadowOffset,
+                g_shadowSize-shadowOffset,
+                g_shadowSize,
+                g_shadowSize ) );
+
+            g_sShadow->setInnerShadowRect(QRect(
+                g_shadowSize-shadowOffset+Metrics::Shadow_Overlap,
+                g_shadowSize-shadowOffset+Metrics::Shadow_Overlap,
+                shadowOffset - 2*Metrics::Shadow_Overlap,
+                shadowOffset - 2*Metrics::Shadow_Overlap ) );
+
+
+            // assign image
+            g_sShadow->setShadow(image);
+
         }
 
-        // assign parameters
-        g_shadowSize = m_internalSettings->shadowSize();
-        g_shadowStrength = m_internalSettings->shadowStrength();
+        setShadow(g_sShadow);
 
-        // setup shadow
-        const int shadowOffset = qMax( 6*g_shadowSize/16, Metrics::Shadow_Overlap*2 );
-        auto decorationShadow = QSharedPointer<KDecoration2::DecorationShadow>::create();
-        decorationShadow->setPadding( QMargins(
-            g_shadowSize-shadowOffset,
-            g_shadowSize-shadowOffset,
-            g_shadowSize,
-            g_shadowSize ) );
-
-        decorationShadow->setInnerShadowRect(QRect(
-            g_shadowSize-shadowOffset+Metrics::Shadow_Overlap,
-            g_shadowSize-shadowOffset+Metrics::Shadow_Overlap,
-            shadowOffset - 2*Metrics::Shadow_Overlap,
-            shadowOffset - 2*Metrics::Shadow_Overlap ) );
-
-        // create image
-        QImage image(2*g_shadowSize, 2*g_shadowSize, QImage::Format_ARGB32_Premultiplied);
-        image.fill(Qt::transparent);
-
-        // create gradient
-        // gaussian delta function
-        auto alpha = [](qreal x) { return std::exp( -x*x/0.15 ); };
-
-        // color calculation delta function
-        auto gradientStopColor = [](QColor color, int alpha)
-        {
-            color.setAlpha(alpha);
-            return color;
-        };
-
-        const QColor shadowColor( m_colorSettings.palette().color( QPalette::Shadow ) );
-
-        QRadialGradient radialGradient( g_shadowSize, g_shadowSize, g_shadowSize);
-        for( int i = 0; i < 10; ++i )
-        {
-            const qreal x( qreal( i )/9 );
-            radialGradient.setColorAt(x,  gradientStopColor(shadowColor, alpha(x)*g_shadowStrength));
-        }
-
-        radialGradient.setColorAt(1, gradientStopColor( shadowColor, 0 ) );
-
-        // fill
-        QPainter painter(&image);
-        painter.setCompositionMode(QPainter::CompositionMode_Source);
-        painter.fillRect( image.rect(), radialGradient);
-
-        // contrast pixel
-        painter.setBrush( Qt::NoBrush );
-        painter.setPen( gradientStopColor(shadowColor, g_shadowStrength) );
-        painter.setRenderHints(QPainter::Antialiasing );
-        painter.drawRoundedRect( QRect( g_shadowSize-shadowOffset, g_shadowSize-shadowOffset, shadowOffset, shadowOffset ), 3, 3 );
-        painter.end();
-
-        // assign to shadow
-        decorationShadow->setShadow(image);
-
-        g_sShadow = decorationShadow;
-        setShadow(decorationShadow);
     }
 
     //_________________________________________________________________
@@ -653,15 +672,15 @@ namespace Breeze
         if( !QX11Info::isPlatformX11() ) return;
 
         // access client
-        KDecoration2::DecoratedClient *c( client().data() );
+        auto c = client().data();
         if( !c ) return;
 
         if( c->windowId() != 0 )
         {
             m_sizeGrip = new SizeGrip( this );
-            connect( client().data(), &KDecoration2::DecoratedClient::maximizedChanged, this, &Breeze::Decoration::updateSizeGripVisibility );
-            connect( client().data(), &KDecoration2::DecoratedClient::shadedChanged, this, &Breeze::Decoration::updateSizeGripVisibility );
-            connect( client().data(), &KDecoration2::DecoratedClient::resizeableChanged, this, &Breeze::Decoration::updateSizeGripVisibility );
+            connect( c, &KDecoration2::DecoratedClient::maximizedChanged, this, &Decoration::updateSizeGripVisibility );
+            connect( c, &KDecoration2::DecoratedClient::shadedChanged, this, &Decoration::updateSizeGripVisibility );
+            connect( c, &KDecoration2::DecoratedClient::resizeableChanged, this, &Decoration::updateSizeGripVisibility );
         }
         #endif
 
