@@ -217,7 +217,7 @@ namespace Breeze
         };
 
         //* exception set
-        typedef QSet<ExceptionId> ExceptionSet;
+        using ExceptionSet = QSet<ExceptionId>;
 
         //* list of white listed special widgets
         /**
